@@ -140,48 +140,49 @@ flextableStyleInternal <- function(styleName, asExpr = FALSE) {
       "header" = list(
         "cell" = officer::fp_cell(
           background.color = "#003399",
-          border = officer::fp_border(color = "white")
+          border = officer::fp_border(color = "#003399")
         ),
-        "text" = officer::fp_text(bold = TRUE, color = "white")
+        "text" = officer::fp_text(bold = TRUE, color = "white", font.size = 11)
       ),
       "header_name" = list(
         "cell" = officer::fp_cell(
           background.color = "#003399",
-          border = officer::fp_border(color = "white")
+          border = officer::fp_border(color = "#003399")
         ),
-        "text" = officer::fp_text(bold = TRUE, color = "white")
+        "text" = officer::fp_text(bold = TRUE, color = "white", font.size = 11, font.family = "calibri")
       ),
       "header_level" = list(
         "cell" = officer::fp_cell(
           background.color = "#003399",
-          border = officer::fp_border(color = "white"),
+          border = officer::fp_border(color = "#003399"),
         ),
-        "text" = officer::fp_text(bold = TRUE, color = "white")
+        "text" = officer::fp_text(bold = TRUE, color = "white", font.size = 11, font.family = "calibri")
       ),
       "column_name" = list(
         "cell" = officer::fp_cell(
           background.color = "#003399",
-          border = officer::fp_border(color = "white"),
+          border = officer::fp_border(color = "#003399"),
         ),
-        "text" = officer::fp_text(bold = TRUE, color = "white")
+        "text" = officer::fp_text(bold = TRUE, color = "white", font.size = 11, font.family = "calibri")
       ),
       "group_label" = list(
         "cell" = officer::fp_cell(
-          background.color = "#4a64bd",
-          border = officer::fp_border(color = "#003399")
+          background.color = "#003399",
+          border = officer::fp_border(color = "#003399", width = 0.5)
         ),
-        "text" = officer::fp_text(bold = TRUE, color = "white")
+        "text" = officer::fp_text(bold = TRUE, color = "white", font.size = 9, font.family = "calibri")
       ),
       "title" = list(
-        "text" = officer::fp_text(bold = TRUE, font.size = 15),
+        "text" = officer::fp_text(bold = TRUE, font.size = 15, font.family = "calibri"),
         "paragraph" = officer::fp_par(text.align = "center")
       ),
       "subtitle" = list(
-        "text" = officer::fp_text(bold = TRUE, font.size = 12),
+        "text" = officer::fp_text(bold = TRUE, font.size = 12, font.family = "calibri"),
         "paragraph" = officer::fp_par(text.align = "center")
       ),
       "body" = list(
-        "cell" = officer::fp_cell(border = officer::fp_border(color = "#003399"))
+        "cell" = officer::fp_cell(border = officer::fp_border(color = "#003399", width = 0.5)),
+        "text" = officer::fp_text(font.size = 9, font.family = "calibri")
       )
     ) |>
       rlang::expr()
@@ -235,30 +236,33 @@ gtStyleInternal <- function(styleName, asExpr = FALSE) {
     style <- list(
       "header" = list(
         gt::cell_fill(color = "#003399"),
-        gt::cell_text(weight = "bold", color = "white", align = "center")
+        gt::cell_text(weight = "bold", color = "white", align = "center", font = "Calibri", size = 11)
       ),
       "header_name" = list(
         gt::cell_fill(color = "#003399"),
-        gt::cell_text(weight = "bold", color = "white", align = "center")
+        gt::cell_text(weight = "bold", color = "white", align = "center", font = "Calibri", size = 11)
       ),
       "header_level" = list(
         gt::cell_fill(color = "#003399"),
-        gt::cell_text(color = "white", weight = "bold", align = "center")
+        gt::cell_text(color = "white", weight = "bold", align = "center", font = "Calibri", size = 11)
       ),
       "column_name" = list(
         gt::cell_fill(color = "#003399"),
-        gt::cell_text(weight = "bold", color = "white", align = "center")
+        gt::cell_text(weight = "bold", color = "white", align = "center", font = "Calibri", size = 11)
       ),
       "group_label" = list(
-        gt::cell_fill(color = "#4a64bd"),
+        gt::cell_fill(color = "#003399"),
         gt::cell_borders(color = "#003399"),
-        gt::cell_text(weight = "bold", color = "white")
+        gt::cell_text(weight = "bold", color = "white", font = "Calibri", size = 9)
       ),
-      "title" = list(gt::cell_text(weight = "bold", size = 15, align = "center")),
+      "title" = list(gt::cell_text(weight = "bold", font = "Calibri", size = 15, align = "center")),
       "subtitle" = list(
-        gt::cell_text(weight = "bold", size = 12, align = "center")
+        gt::cell_text(weight = "bold", size = 12, font = "Calibri", align = "center")
       ),
-      body = list(gt::cell_borders(color = "#003399"))
+      body = list(
+        gt::cell_borders(color = "#003399", weight = 0.5),
+        gt::cell_text(font = "calibri", size = 9)
+        )
     ) |>
       rlang::expr()
   }
@@ -312,7 +316,7 @@ tinytableStyleInternal <- function(styleName, asExpr = FALSE) {
         "bold" = TRUE, background = "#003399", line = "lbtr", line_color = "#003399", color = "white"
       ),
       "group_label" = list(
-        "bold" = TRUE, background = "#4a64bd", line = "lbtr", line_color = "#003399", color = "white"
+        "bold" = TRUE, background = "#003399", line = "lbtr", line_color = "#003399", color = "white"
       ),
       "body" = list(line = "lbtr", line_color = "#003399")
     ) |>
