@@ -36,7 +36,7 @@ test_that("fxTableInternal", {
   header_col_style <- fxResult$header$styles$cells$background.color$data[, "Study cohorts\ncohort1\nStudy strata\noverall\noverall"]
   expect_equal(header_col_style, c("#c8c8c8", "#c8c8c8", "#e1e1e1", "#c8c8c8", "#e1e1e1", "#e1e1e1"))
   expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0.8, 1.5, 0))
+  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(1.5, 0))
   expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "black")
   expect_equal(fxResult$header$styles$text$bold$data[, "cdm_name"] |> unique(), TRUE)
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"][1], "blue")
@@ -92,7 +92,7 @@ test_that("fxTableInternal", {
   header_col_style <- fxResult$header$styles$cells$background.color$data[, "strata_name\noverall\nstrata_level\noverall"]
   expect_equal(header_col_style, c("black", "black", "black", "transparent", "black", "transparent"))
   expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0.8, 1.5, 0))
+  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(1.5, 0))
   expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "black")
   expect_equal(fxResult$header$styles$text$bold$data[, "cdm_name"] |> unique(), TRUE)
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"], c("black", "blue", "black", "black", "black", "black"))
@@ -171,7 +171,6 @@ test_that("fxTableInternal, test default styles and NULL", {
   expect_equal(unique(fxResult$header$styles$cells$background.color$data[, "Study cohorts\ncohort1\nStudy strata\noverall\noverall"]),
                "transparent")
   expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fxResult$header$styles$cells$border.width.top$data[1,] |> unique(), 0.8)
   expect_equal(fxResult$header$styles$cells$border.width.top$data[2,] |> unique(), 1.5)
   expect_equal(fxResult$header$styles$cells$border.width.top$data[3,] |> unique(), 0)
   expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "black")
@@ -191,7 +190,7 @@ test_that("fxTableInternal, test default styles and NULL", {
     formatHeader(header = c("Strata", "strata_name", "strata_level"),
                  includeHeaderName = TRUE) |>
     dplyr::select(-result_id)
-  style <- tableStyleCode(type = "flextable") |> rlang::eval_bare()
+  style <- validateStyle(style = "default", obj = "table", type = "flextable")
   fxResult <- fxTableInternal(
     table_to_format,
     style = style,
@@ -207,9 +206,9 @@ test_that("fxTableInternal, test default styles and NULL", {
   # Spanner styles
   header_col_style <- fxResult$header$styles$cells$background.color$data[, "Strata\nstrata_name\noverall\nstrata_level\noverall"]
   expect_equal(header_col_style, c("transparent", "transparent", "#c8c8c8", "#d9d9d9", "#e1e1e1", "#d9d9d9", "#e1e1e1"))
-  expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0.8, 1))
-  expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "gray")
+  expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), c("transparent", "#e1e1e1"))
+  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(1))
+  expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), c("#e1e1e1", "#c8c8c8"))
   expect_true(fxResult$header$styles$text$bold$data[, "cdm_name"] |> unique())
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"] |> unique(), "black")
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"] |> unique(), "black")
@@ -217,7 +216,7 @@ test_that("fxTableInternal, test default styles and NULL", {
 
   # body
   expect_equal(fxResult$body$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), 1)
-  expect_equal(fxResult$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "gray")
+  expect_equal(fxResult$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "#c8c8c8")
   expect_equal(fxResult$body$styles$cells$background.color$data[, "cdm_name"],
                c("#e9e9e9", "transparent", "transparent", "transparent", "transparent","transparent",
                  "#e9e9e9","transparent", "transparent", "transparent", "transparent", "transparent"))
@@ -228,7 +227,7 @@ test_that("fxTableInternal, test merge", {
   table_to_format<- mockSummarisedResult() |>
     formatHeader(header = c("strata_name", "strata_level")) |>
     dplyr::select(-result_id)
-  style <- tableStyleCode(type = "flextable") |> rlang::eval_bare()
+  style <- validateStyle(style = "default", obj = "table", type = "flextable")
   fxResult <- fxTableInternal(
     x = table_to_format,
     style = style,
@@ -242,14 +241,14 @@ test_that("fxTableInternal, test merge", {
     merge = "all_columns"
   )
 
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,1],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,2],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,5],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,16],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,1] |> unique(),
+               c("#c8c8c8"))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,2] |> unique(),
+               c("#c8c8c8"))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,5] |> unique(),
+               c("#c8c8c8"))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,16] |> unique(),
+               c("#c8c8c8"))
 
   # merge = c("cdm_name", "variable_name")
   fxResult <- fxTableInternal(
@@ -264,12 +263,12 @@ test_that("fxTableInternal, test merge", {
     groupOrder = NULL,
     merge = c("cdm_name", "variable_name")
   )
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,1],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,2],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,4],
-               c('gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray', 'gray'))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,1] |> unique(),
+               c("#c8c8c8"))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,2] |> unique(),
+               c("#c8c8c8"))
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,4] |> unique(),
+               c("#c8c8c8"))
 })
 
 test_that("multiple groupColumn", {
@@ -307,7 +306,7 @@ test_that("multiple groupColumn", {
   header_col_style <- fxResult$header$styles$cells$background.color$data[, "strata_name:overall:strata_level:overall"]
   expect_equal(header_col_style, c("black", "black", "black", "transparent", "black", "transparent"))
   expect_equal(fxResult$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0.8, 1.5, 0))
+  expect_equal(fxResult$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(1.5, 0))
   expect_equal(fxResult$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "black")
   expect_equal(all(fxResult$header$styles$text$bold$data[, "cdm_name"] == c(FALSE, TRUE, FALSE, FALSE, FALSE, FALSE)), TRUE)
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"], c("black", "blue", "black", "black", "black", "black"))
