@@ -160,6 +160,17 @@ test_that("global options works", {
   expect_true(class(tab)[1] == "tinytable")
   tab <- visTable(result, type = "gt")
   expect_true(class(tab)[1] == "gt_tbl")
-  options(visOmopResults.tableStyle = NULL)
-  options(visOmopResults.tableType = NULL)
+  setGlobalTableOptions()
+})
+
+test_that("warnings", {
+  result <- mockSummarisedResult()
+  expect_message(visTable(result, type = "reactable", .options = list(caption = "HI")))
+  expect_message(visTable(result, type = "tinytable", .options = list(title = "HI")))
+  expect_message(visTable(result, type = "datatable", .options = list(title = "HI")))
+  expect_message(visTable(result, type = "tibble", .options = list(title = "HI")))
+  expect_no_message(visTable(result, type = "reactable"))
+  expect_no_message(visTable(result, type = "tinytable"))
+  expect_no_message(visTable(result, type = "datatable"))
+  expect_no_message(visTable(result, type = "tibble"))
 })
